summaryrefslogtreecommitdiffstats
path: root/crypto/rc4
diff options
context:
space:
mode:
authorAndy Polyakov <appro@openssl.org>2007-11-11 20:06:17 +0000
committerAndy Polyakov <appro@openssl.org>2007-11-11 20:06:17 +0000
commit2ea3cd8abca03c7abaa70b4c128fac04e769b466 (patch)
treec68ddb4fb105f35a10c198dd6d26b1ee22d0351a /crypto/rc4
parent095db72024d34163aa327997f5808b8c3a01f3ea (diff)
Comply with updated x86cpuid.pl.
Diffstat (limited to 'crypto/rc4')
-rw-r--r--crypto/rc4/rc4_skey.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/crypto/rc4/rc4_skey.c b/crypto/rc4/rc4_skey.c
index b22c40b0bd..46b77ec321 100644
--- a/crypto/rc4/rc4_skey.c
+++ b/crypto/rc4/rc4_skey.c
@@ -119,14 +119,15 @@ void RC4_set_key(RC4_KEY *key, int len, const unsigned char *data)
* implementations suffer from significant performance
* losses then, e.g. PIII exhibits >2x deterioration,
* and so does Opteron. In order to assure optimal
* all-round performance, let us [try to] detect P4 at
* run-time by checking upon HTT bit in CPU capability
* vector and set up compressed key schedule, which is
* recognized by correspondingly updated assembler
- * module...
+ * module... Bit 20 is set up by OPENSSL_ia32_cpuid.
+ *
* <appro@fy.chalmers.se>
*/
- if (OPENSSL_ia32cap_P & (1<<28)) {
+ if (OPENSSL_ia32cap_P & (1<<20)) {
unsigned char *cp=(unsigned char *)d;
for (i=0;i<256;i++) cp[i]=i;
@@ -119,14 +119,15 @@ void RC4_set_key(RC4_KEY *key, int len, const unsigned char *data)
* losses then, e.g. PIII exhibits >2x deterioration,
* and so does Opteron. In order to assure optimal
- * all-round performance, let us [try to] detect P4 at
- * run-time by checking upon HTT bit in CPU capability
+ * all-round performance, we detect P4 at run-time by
+ * checking upon reserved bit 20 in CPU capability
* vector and set up compressed key schedule, which is
* recognized by correspondingly updated assembler